# UI/UX Feedback

**ID:** Feedback-20260130-160358
**URL:** idea://003. Feature-Toolbox Design/mockups/stage-toolbox-modal-v2.html
**Date:** 2026-01-30 16:04:17

## Selected Elements

- `{'selector': 'div.accordion-header', 'parents': ['div.modal', 'div.modal-body', 'div.accordion', 'div.accordion-item.expanded']}`

## Feedback

below feature stage, add a stage called "Pentest"

## Screenshot

![Screenshot](./page-screenshot.png)
